@@ -52,7 +52,7 @@ class SessionMiddleware:
             self.security_flags += "; secure"
 
     async def __call__(self, scope: Scope, receive: Receive, send: Send) -> None:
-        if scope["type"] not in ("http", "websocket"):  # pragma: no cover
+        if scope["type"] not in ("websocket"):  # pragma: no cover
             await self.app(scope, receive, send)
             return
 
